<!DOCTYPE html>
<html lang="es" prefix="og: http://ogp.me/ns#">

<head>
    <meta charset="UTF-8">
    <meta name="dc.language" scheme="rfc1766" content="spanish">
    <meta http-equiv="Content-Language" content="es">
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
    <meta name="viewport" content="width=device-width, minimum-scale=1.0, maximum-scale=1.0, initial-scale=1.0, user-scalable=no">
    <meta name="HandheldFriendly" content="true">
    <meta name="resource-type" content="document">
    <meta name="revisit-after" content="3 days">
    <meta name="robots" content="all">

    <link rel="shortcut icon" href="<?= get_template_directory_uri() ?>/images/favicon.png" />
    <link rel="apple-touch-icon" href="<?= get_template_directory_uri() ?>/images/favicon.png" />

    <link rel="stylesheet" href="<?= get_template_directory_uri() ?>/assets/css/normalize.css" type="text/css">
    <link rel="stylesheet" href="<?= get_template_directory_uri() ?>/assets/css/blog.css" type="text/css">

    <?php wp_head(); ?>
</head>

<body>
    <div id="menumodal" class="menu-popup hidden">
        <button type="button" class="popup-close" id="modalclose">
            X
        </button>
        <div class="left-container">
            <nav class="nav">
                <ul class="list">
                    <li class="list__item">
                        <div class="list__button">
                            <a href="https://dimark.co" class="nav__link">Inicio</a>
                        </div>
                    </li>
                    <li class="list__item list_item--click">
                        <div class="list__button list__button--click">
                            <a href="https://dimark.co/servicios/" class="nav__link">Servicios</a>
                            <img src="/wp-content/themes/dimark/images/arrow.svg" alt="arrow" class="list__arrow">
                        </div>
                        <ul class="list__show">
                            <li class="list__inside">
                                <a href="https://dimark.co/servicios/pagina-web/" class="nav__link nav__link--inside">Paginas web</a>
                            </li>
                            <li class="list__inside">
                                <a href="https://dimark.co/servicios/seo/" class="nav__link nav__link--inside">SEO</a>
                            </li>
                        </ul>
                    </li>
                    <li class="list__item list_item--click">
                        <div class="list__button list__button--click">
                            <a href="#" class="nav__link">Casos de éxito</a>
                            <img src="/wp-content/themes/dimark/images/arrow.svg" alt="arrow" class="list__arrow">
                        </div>
                        <ul class="list__show">
                            <li class="list__inside">
                                <a href="https://dimark.co/casos-de-exito/web/" class="nav__link nav__link--inside">Web</a>
                            </li>
                            <li class="list__inside">
                                <a href="https://dimark.co/casos-de-exito/seo/" class="nav__link nav__link--inside">SEO</a>
                            </li>
                            <li class="list__inside">
                                <a href="https://dimark.co/casos-de-exito/sem/" class="nav__link nav__link--inside">SEM</a>
                            </li>
                            <li class="list__inside">
                                <a href="https://dimark.co/casos-de-exito/creacion-de-contenido/" class="nav__link nav__link--inside">Creación de contenido UGC</a>
                            </li>
                        </ul>
                    </li>
                    <li class="list__item">
                        <div class="list__button">
                            <a href="https://dimark.co/desarrollos-propios/" class="nav__link">Desarrollos propios</a>
                        </div>
                    </li>
                    <li class="list__item">
                        <div class="list__button">
                            <a href="https://dimark.co/somos-grupo-dimark/" class="nav__link">Somos Grupo Dimark</a>
                        </div>
                    </li>
                    <li class="list__item">
                        <div class="list__button">
                            <a href="https://dimark.co/contactenos/" class="nav__link">Contáctenos</a>
                        </div>
                    </li>
                </ul>
            </nav>
        </div>
        <div class="right-container">
            <img class="img" src="/wp-content/themes/dimark/images/logo6.png" alt="logo" />
            <div class="list-item">
                <h3>Teléfono</h3>
                <p>320 392 05 99</p>
            </div>
            <div class="list-item">
                <h3>Email</h3>
                <p>info@dimark.co</p>
            </div>
            <div class="icons-wrapper">
                <a href="https://www.facebook.com/profile.php?id=100043754966551" target="_blank">
                    <svg xmlns="http://www.w3.org/2000/svg" width="10" height="16" viewBox="0 0 24 24" fill="currentColor" class="facebook-icon icon icon-tabler icons-tabler-filled icon-tabler-brand-facebook">
                        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                        <path d="M18 2a1 1 0 0 1 .993 .883l.007 .117v4a1 1 0 0 1 -.883 .993l-.117 .007h-3v1h3a1 1 0 0 1 .991 1.131l-.02 .112l-1 4a1 1 0 0 1 -.858 .75l-.113 .007h-2v6a1 1 0 0 1 -.883 .993l-.117 .007h-4a1 1 0 0 1 -.993 -.883l-.007 -.117v-6h-2a1 1 0 0 1 -.993 -.883l-.007 -.117v-4a1 1 0 0 1 .883 -.993l.117 -.007h2v-1a6 6 0 0 1 5.775 -5.996l.225 -.004h3z" />
                    </svg>
                </a>
                <a href="https://www.instagram.com/dimark.co/" target="_blank">
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="instagram-icon icon icon-tabler icons-tabler-outline icon-tabler-brand-instagram">
                        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                        <path d="M4 4m0 4a4 4 0 0 1 4 -4h8a4 4 0 0 1 4 4v8a4 4 0 0 1 -4 4h-8a4 4 0 0 1 -4 -4z" />
                        <path d="M12 12m-3 0a3 3 0 1 0 6 0a3 3 0 1 0 -6 0" />
                        <path d="M16.5 7.5l0 .01" />
                    </svg>
                </a>
                <a href="https://www.tiktok.com/@dimark.co" target="_blank">
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="currentColor" class="tiktok-icon icon icon-tabler icons-tabler-filled icon-tabler-brand-tiktok">
                        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                        <path d="M16.083 2h-4.083a1 1 0 0 0 -1 1v11.5a1.5 1.5 0 1 1 -2.519 -1.1l.12 -.1a1 1 0 0 0 .399 -.8v-4.326a1 1 0 0 0 -1.23 -.974a7.5 7.5 0 0 0 1.73 14.8l.243 -.005a7.5 7.5 0 0 0 7.257 -7.495v-2.7l.311 .153c1.122 .53 2.333 .868 3.59 .993a1 1 0 0 0 1.099 -.996v-4.033a1 1 0 0 0 -.834 -.986a5.005 5.005 0 0 1 -4.097 -4.096a1 1 0 0 0 -.986 -.835z" />
                    </svg>
                </a>
            </div>
        </div>

    </div>
    <header class="header">
        <a href="https://dimark.co">
            <img src="/wp-content/themes/dimark/images/logoheader.png" class="logo-header w-[120px] h-[60px] object-contain ml-10" alt="logo dimark" />
        </a>
        <?php /*the_content();*/ ?>
        <div class="header-items-wrapper">
            <div class="header-icons-wrapper">
                <a href="https://www.facebook.com/profile.php?id=100043754966551" target="_blank" class="header-icon">
                    <svg xmlns="http://www.w3.org/2000/svg" width="10" height="16" viewBox="0 0 24 24" fill="currentColor" class="facebook-icon icon icon-tabler icons-tabler-filled icon-tabler-brand-facebook">
                        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                        <path d="M18 2a1 1 0 0 1 .993 .883l.007 .117v4a1 1 0 0 1 -.883 .993l-.117 .007h-3v1h3a1 1 0 0 1 .991 1.131l-.02 .112l-1 4a1 1 0 0 1 -.858 .75l-.113 .007h-2v6a1 1 0 0 1 -.883 .993l-.117 .007h-4a1 1 0 0 1 -.993 -.883l-.007 -.117v-6h-2a1 1 0 0 1 -.993 -.883l-.007 -.117v-4a1 1 0 0 1 .883 -.993l.117 -.007h2v-1a6 6 0 0 1 5.775 -5.996l.225 -.004h3z" />
                    </svg>
                </a>
                <a href="https://www.instagram.com/dimark.co/" target="_blank" class="header-icon">
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="instagram-icon icon icon-tabler icons-tabler-outline icon-tabler-brand-instagram">
                        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                        <path d="M4 4m0 4a4 4 0 0 1 4 -4h8a4 4 0 0 1 4 4v8a4 4 0 0 1 -4 4h-8a4 4 0 0 1 -4 -4z" />
                        <path d="M12 12m-3 0a3 3 0 1 0 6 0a3 3 0 1 0 -6 0" />
                        <path d="M16.5 7.5l0 .01" />
                    </svg>
                </a>
                <a href="https://www.tiktok.com/@dimark.co" target="_blank" class="header-icon ">
                    <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="currentColor" class="tiktok-icon icon icon-tabler icons-tabler-filled icon-tabler-brand-tiktok">
                        <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                        <path d="M16.083 2h-4.083a1 1 0 0 0 -1 1v11.5a1.5 1.5 0 1 1 -2.519 -1.1l.12 -.1a1 1 0 0 0 .399 -.8v-4.326a1 1 0 0 0 -1.23 -.974a7.5 7.5 0 0 0 1.73 14.8l.243 -.005a7.5 7.5 0 0 0 7.257 -7.495v-2.7l.311 .153c1.122 .53 2.333 .868 3.59 .993a1 1 0 0 0 1.099 -.996v-4.033a1 1 0 0 0 -.834 -.986a5.005 5.005 0 0 1 -4.097 -4.096a1 1 0 0 0 -.986 -.835z" />
                    </svg>
                </a>
            </div>
            <button type="button" class="header-hamburger-button" id="modalbutton">
                <svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="hamburger-icon icon icon-tabler icons-tabler-outline icon-tabler-menu-2">
                    <path stroke="none" d="M0 0h24v24H0z" fill="none" />
                    <path d="M4 6l16 0" />
                    <path d="M4 12l16 0" />
                    <path d="M4 18l16 0" />
                </svg>
            </button>
        </div>
    </header>
	
	
	